# -*- coding: utf-8 -*-

from django import forms
from models import BaseEvent, GlobalEvent, TeamEvent, Attendee, TeamEventComment


class BaseEventForm(forms.ModelForm):
    """ 
    a form to create/update a BaseEvent
    """
    class Meta:
        model = BaseEvent
        exclude = ('date_created')

    class Media:
        css = {'all': (
                       '/media/jquery-ui/css/css/smoothness/jquery-ui.css',
                       '/media/jquery-ui-timepicker/css/ui-lightness/ui.timepickr.css',
                       )}
        js = (
              '/media/jquery/jquery.js',
              '/media/jquery-ui/jquery-ui.js',
              '/media/jquery-ui-timepicker/js/jquery.timepickr.min.js',
              '/media/jquery-ui-timepicker/js/ui.timepickr.min.js',
              '/media/js/events-ui.js',
              )
        
    def __init__(self, *args, **kargs):
        super(BaseEventForm, self).__init__(*args, **kargs)
        self.fields['date_begin'].widget = forms.SplitDateTimeWidget()
        self.fields['date_end'].widget = forms.SplitDateTimeWidget()
        
    def clean(self):
        begin = self.cleaned_data.get('date_begin')
        end = self.cleaned_data.get('date_end')
        if begin and end and begin > end:
            raise forms.ValidationError("Events can not end before they start.")
        return self.cleaned_data


class TeamEventForm(BaseEventForm):
    """ 
    a form to create/update a TeamEvent
    """
    class Meta(BaseEventForm.Meta):
        model = TeamEvent
        exclude = ('teams', 'date_created')
        
        
class GlobalEventForm(BaseEventForm):
    """ 
    a form to create/update a GlobalEvent
    """
    class Meta(BaseEventForm.Meta):
        model = GlobalEvent


class AttendeeRegistrationForm(forms.ModelForm):
    """
    a form to create/update an Attendee object
    """
    def __init__(self, *args, **kargs):
        super(AttendeeRegistrationForm, self).__init__(*args, **kargs)
        self.fields['guests'].min_value = 0

    class Meta:
        model = Attendee
        exclude = ('attendee', 'team_event')

class TeamEventCommentForm(forms.ModelForm):
    """
    a form to comment a team event
    """
    class Meta:
        model = TeamEventComment
        exclude = ('team_event', 'date_created', 'comment_by')

