# -*- coding: utf-8 -*-

from django.template import RequestContext
from django.utils.translation import ugettext_lazy as _
from django.utils.translation import ugettext
from django.core import serializers

from django.contrib.auth.decorators import login_required
from django.db.models import Q

from django.shortcuts import get_object_or_404
from django.shortcuts import render_to_response

from django import http

from common.utils import redirect
from common import launchpad

from models import Team

import forms

def reapprovals(request):
    teams = Team.objects.all().order_by('expires_date')
    approved_teams = filter(lambda a: a.approved, teams)
    context = {
        'approved_teams': approved_teams,
    }
    return render_to_response('teams/team_reapprovals.html', 
                context, RequestContext(request))

def team_list(request):
    team_list = Team.objects.all().order_by('name')
    
    form = forms.TeamSearchForm(data=request.GET)
    if form.is_valid():
        if form.cleaned_data['q']:
            q = form.cleaned_data['q']
            team_list = team_list.filter(Q(name__icontains=q) | Q(country__icontains=q) | Q(city__icontains=q))

    context = {
        'team_list': team_list,
        'form': form,
    }
    return render_to_response('teams/team_list.html', context,
                  RequestContext(request))

def team_event_list(request, team_slug):
    """
    list with all team events in present and future for the given team
    """
    team_object = get_object_or_404(Team, lp_name=team_slug)
    team_event_list = team_object.teamevent_set.next_events()
    print team_event_list
    context = {
        'team_object': team_object,
        'team_event_list': team_event_list,
    }
    return render_to_response('teams/team_event_list.html', context,
                  RequestContext(request))

def team_detail(request, team_slug):
    team_object = get_object_or_404(Team, lp_name=team_slug)
    context = {
        'team': team_object,
    }
    return render_to_response('teams/team_detail.html', 
                                         context, RequestContext(request))


@login_required
def team_edit(request, team_slug):
    #get team
    team_object = get_object_or_404(Team, lp_name=team_slug)
    
    #check if user has needed rights
    is_on_lc = launchpad.is_user_on_loco_council(request.user)
    is_contact = launchpad.is_admin_or_owner(request.user.username, team_object)
    if not is_on_lc and not is_contact:
        request.user.message_set.create(message=ugettext('You are not allowed to make changes to the team details.'))
        return redirect( team_object )

    if request.method == "POST":
        if is_on_lc:
            form = forms.LoCoCouncilForm(data=request.POST, instance=team_object)
        else:
            form = forms.UpdateTeamForm(data=request.POST, instance=team_object)
        if form.is_valid():
            form.save()
            request.user.message_set.create(message=ugettext('Team details updated'))
            return redirect( team_object )
        else:
            request.user.message_set.create(message=ugettext('Team details could not be saved.'))
    else:
        if is_on_lc:
            form = forms.LoCoCouncilForm(instance=team_object)
        else:
            form = forms.UpdateTeamForm(instance=team_object)
    
    return render_to_response('teams/team_update.html', 
                    {'form': form, 
                     'team':team_object, 
                     'user':request.user, 
                    }, RequestContext(request))

def xml_team_data(request):
    XMLSerializer = serializers.get_serializer("xml")
    xml_serializer = XMLSerializer()
    xml_serializer.serialize(Team.objects.all())
    data = xml_serializer.getvalue()
    response = http.HttpResponse(data, mimetype='text/xml')
    response['Content-Disposition'] = 'filename=locoteams.xml'
    return response
